from fastapi import FastAPI, HTTPException, Header
from app.database import create_table, insert_customer, get_customers
from pydantic import BaseModel
from typing import List, Optional

app = FastAPI()

API_KEY = "sicherespw"

class Customer(BaseModel):
    name: str
    email: str

@app.on_event("startup")
def startup():
    create_table()

@app.post("/customers/")
def create_customer(customer: Customer, x_api_key: Optional[str] = Header(None)):
    if x_api_key != API_KEY:
        raise HTTPException(status_code=401, detail="Unauthorized: API-Key fehlt oder ist falsch")
    insert_customer(customer.name, customer.email)
    return {"message": "Customer created"}

@app.get("/customers/", response_model=List[Customer])
def read_customers():
    return get_customers()
